@@ -1,7 +1,8 @@
 from wavencoder.models.wav2vec import Wav2Vec
-from wavencoder.models.wav2vec2 import Wav2Vec2Model
+# from wavencoder.models.wav2vec2 import Wav2Vec2Model
 from wavencoder.models.sincnet import SincNet, SincConvLayer
 from wavencoder.models.lstm_classifier import LSTM_Classifier
 from wavencoder.models.lstm_classifier import LSTM_Attn_Classifier
 from wavencoder.models.baseline import CNN1d
-from wavencoder.models.attention import DotAttention, SoftAttention
\ No newline at end of file
+# from wavencoder.models.attention import DotAttention, SoftAttention
+from wavencoder.models.rawnet import RawNet2Model
\ No newline at end of file
